@@ -142,11 +142,13 @@ class GPUType(ExpiredValueObject):
 class InstanceTypeStatus(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
-
+    def is_available(self):
+        return self.value=='Available'
 class InstanceTypeStatusCategory(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
-
+    def is_with_stock(self):
+        return self.value=='WithStock'
 class Time(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
