@@ -1,5 +1,5 @@
 import os, json, time
-from typing import List, Optional, Tuple
+from typing import List, Optional, Tuple, Union
 from ddd_objects.infrastructure.repository_impl import RepositoryImpl
 from ddd_objects.infrastructure.repository_impl import (
     RepositoryImpl, 
@@ -125,8 +125,16 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             cluster_name=cluster_name
         )
 
-    def add_node_label(self, node_infos: List[NodeInfo], key: Key, value: Value)->Optional[List[CommandResult]]:
-        node_infos = [node_info_converter.to_do(x) for x in node_infos]
+    def add_node_label(
+        self, 
+        node_infos: List[Union[NodeInfo, NodeMeta]], 
+        key: Key, 
+        value: Value
+    )->Optional[List[CommandResult]]:
+        node_infos = [
+            node_info_converter.to_do(x) if isinstance(x, NodeInfo) 
+            else node_meta_converter.to_do(x)
+            for x in node_infos]
         key = key.get_value()
         value = value.get_value()
         result = self.ao.add_node_label(node_infos, key, value)
